@@ -3,7 +3,7 @@
 
    Copyright (c) 1997 Riku Kalinen, OH2LWO, oh2lwo@sral.fi
 
-   RCS $Header: /home/mole/riku/CVS/yaesu/yaesu.c,v 1.2 1997/12/11 15:02:05 riku Exp $ */
+   RCS $Header: /home/mole/riku/CVS/yaesu/yaesu.c,v 1.3 1998/05/08 11:41:40 riku Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -1430,7 +1430,11 @@ unsigned char calculate_vx1_cksum (unsigned char *b1, int size)
   
   for (i = 0; i < size; i ++) cksum += b1[i];
 
+#ifdef USE_ALTERNATE_VX1_CKSUM
+  cksum = 0xf0 - cksum - USE_ALTERNATE_VX1_CKSUM;
+#else
   cksum = 0xf0 - cksum;
+#endif
 
   return cksum;
 }
@@ -1442,7 +1446,11 @@ unsigned char calculate_vx1_cksum_2 (unsigned char *b1, int size)
   
   for (i = 0; i < size; i ++) cksum += b1[i];
 
+#ifdef USE_ALTERNATE_VX1_CKSUM
+  cksum = cksum + 0x10 + USE_ALTERNATE_VX1_CKSUM;
+#else
   cksum = cksum + 0x10;
+#endif
 
   return cksum;
 }
